# Generated by Django 5.0.1 on 2024-06-07 00:32

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("testapp", "0002_user_preferred_language"),
        migrations.swappable_dependency(settings.BASEAPP_PROFILES_PROFILE_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="profile",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(class)s",
                to=settings.BASEAPP_PROFILES_PROFILE_MODEL,
                verbose_name="profile",
            ),
        ),
    ]
