# Generated by Django 4.2.13 on 2024-06-28 00:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("testapp", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="preferred_language",
            field=models.CharField(
                choices=[("en", "English"), ("es", "Spanish"), ("pt", "Portuguese")],
                default="en",
                max_length=9,
            ),
        ),
    ]
